package com.ruoyi.pay.controller;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.pay.domain.vo.PayAttendanceVo;
import com.ruoyi.pay.domain.bo.PayAttendanceBo;
import com.ruoyi.pay.service.IPayAttendanceService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 考勤
 *
 * @author ruoyi
 * @date 2025-05-12
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/pay/attendance")
public class PayAttendanceController extends BaseController {

    private final IPayAttendanceService iPayAttendanceService;

    /**
     * 查询考勤列表
     */
    @SaCheckPermission("pay:attendance:list")
    @GetMapping("/list")
    public TableDataInfo<PayAttendanceVo> list(PayAttendanceBo bo, PageQuery pageQuery) {
        return iPayAttendanceService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出考勤列表
     */
    @SaCheckPermission("pay:attendance:export")
    @Log(title = "考勤", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(PayAttendanceBo bo, HttpServletResponse response) {
        List<PayAttendanceVo> list = iPayAttendanceService.queryList(bo);
        ExcelUtil.exportExcel(list, "考勤", PayAttendanceVo.class, response);
    }

    /**
     * 获取考勤详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("pay:attendance:query")
    @GetMapping("/{id}")
    public R<PayAttendanceVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iPayAttendanceService.queryById(id));
    }

    /**
     * 新增考勤
     */
    @SaCheckPermission("pay:attendance:add")
    @Log(title = "考勤", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody PayAttendanceBo bo) {
        return toAjax(iPayAttendanceService.insertByBo(bo));
    }

    /**
     * 修改考勤
     */
    @SaCheckPermission("pay:attendance:edit")
    @Log(title = "考勤", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody PayAttendanceBo bo) {
        return toAjax(iPayAttendanceService.updateByBo(bo));
    }

    /**
     * 删除考勤
     *
     * @param ids 主键串
     */
    @SaCheckPermission("pay:attendance:remove")
    @Log(title = "考勤", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iPayAttendanceService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
